@@ -19,6 +19,7 @@
 
 #include <QApplication>
 #include <KAboutData>
+#include <KCrash>
 #include <KDBusService>
 #include <KLocalizedString>
 #include <QCommandLineParser>
@@ -26,6 +27,18 @@
 #include "MuonDiscoverMainWindow.h"
 #include <DiscoverBackendsFactory.h>
 #include "DiscoverVersion.h"
+#include <QTextStream>
+
+MuonDiscoverMainWindow::CompactMode decodeCompactMode(const QString &str)
+{
+    if (str == QLatin1String("auto"))
+        return MuonDiscoverMainWindow::Auto;
+    else if (str == QLatin1String("compact"))
+        return MuonDiscoverMainWindow::Compact;
+    else if (str == QLatin1String("full"))
+        return MuonDiscoverMainWindow::Full;
+    return MuonDiscoverMainWindow::Full;
+}
 
 int main(int argc, char** argv)
 {
@@ -33,12 +46,15 @@ int main(int argc, char** argv)
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("muondiscover")));
     app.setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    KLocalizedString::setApplicationDomain("muon-discover");
+#ifdef WITH_KCRASH_INIT
+    KCrash::initialize();
+#endif
+    KLocalizedString::setApplicationDomain("plasma-discover");
     KAboutData about(QStringLiteral("muondiscover"), i18n("Discover"), version, i18n("An application explorer"),
-                     KAboutLicense::GPL, i18n("© 2010-2014 Plasma Development Team"));
+                     KAboutLicense::GPL, i18n("© 2010-2016 Plasma Development Team"));
     about.addAuthor(i18n("Aleix Pol Gonzalez"), QString(), QStringLiteral("aleixpol@blue-systems.com"));
     about.addAuthor(i18n("Jonathan Thomas"), QString(), QStringLiteral("echidnaman@kubuntu.org"));
-    about.setProductName("muon/discover");
+    about.setProductName("discover/discover");
     KAboutData::setApplicationData(about);
 
     KDBusService service(KDBusService::Unique);
@@ -50,15 +66,25 @@ int main(int argc, char** argv)
         parser.addOption(QCommandLineOption(QStringLiteral("category"), i18n("Display a list of entries with a category."), QStringLiteral("name")));
         parser.addOption(QCommandLineOption(QStringLiteral("mode"), i18n("Open Discover in a said mode. Modes correspond to the toolbar buttons."), QStringLiteral("name")));
         parser.addOption(QCommandLineOption(QStringLiteral("listmodes"), i18n("List all the available modes.")));
-        parser.addPositionalArgument(QStringLiteral("urls"), i18n("Supports appstream: url scheme (experimental)"));
+        parser.addOption(QCommandLineOption(QStringLiteral("compact"), i18n("Compact Mode (auto/compact/full)."), QStringLiteral("mode"), QStringLiteral("auto")));
+        parser.addOption(QCommandLineOption(QStringLiteral("test"), QStringLiteral("Test file"), QStringLiteral("file.qml")));
+        parser.addPositionalArgument(QStringLiteral("urls"), i18n("Supports appstream: url scheme"));
         DiscoverBackendsFactory::setupCommandLine(&parser);
-        about.setupCommandLine(&parser);parser.addHelpOption();
+        about.setupCommandLine(&parser);
+        parser.addHelpOption();
         parser.addVersionOption();
         parser.process(app);
         about.processCommandLine(&parser);
-        DiscoverBackendsFactory::processCommandLine(&parser);
+        DiscoverBackendsFactory::processCommandLine(&parser, parser.isSet(QStringLiteral("test")));
 
-        mainWindow = new MuonDiscoverMainWindow;
+        if(parser.isSet(QStringLiteral("listmodes"))) {
+            QTextStream(stdout) << i18n("Available modes:\n");
+            foreach(const QString& mode, mainWindow->modes())
+                QTextStream(stdout) << " * " << mode << '\n';
+            return 0;
+        }
+
+        mainWindow = new MuonDiscoverMainWindow(decodeCompactMode(parser.value(QStringLiteral("compact"))));
         QObject::connect(&app, &QApplication::aboutToQuit, mainWindow, &MuonDiscoverMainWindow::deleteLater);
 
         if(parser.isSet(QStringLiteral("application")))
@@ -67,25 +93,30 @@ int main(int argc, char** argv)
             mainWindow->openMimeType(parser.value(QStringLiteral("mime")));
         else if(parser.isSet(QStringLiteral("category")))
             mainWindow->openCategory(parser.value(QStringLiteral("category")));
-        else if(parser.isSet(QStringLiteral("mode")))
+
+        if(parser.isSet(QStringLiteral("mode")))
             mainWindow->openMode(parser.value(QStringLiteral("mode")).toLocal8Bit());
-        else if(parser.isSet(QStringLiteral("listmodes"))) {
-            fprintf(stdout, "%s", qPrintable(i18n("Available modes:\n")));
-            foreach(const QString& mode, mainWindow->modes())
-                fprintf(stdout, " * %s\n", qPrintable(mode));
-            return 0;
-        }
 
         foreach(const QString &arg, parser.positionalArguments()) {
             QUrl url(arg);
             if (url.scheme() == QLatin1String("appstream")) {
-                mainWindow->openApplication(url.path());
+                mainWindow->openApplication(url.host());
+            } else {
+                QTextStream(stdout) << "unrecognized url" << url.toDisplayString() << '\n';
+                return 1;
             }
         }
+
+        if (parser.isSet(QStringLiteral("test"))) {
+            const QUrl testFile = QUrl::fromUserInput(parser.value(QStringLiteral("test")), {}, QUrl::AssumeLocalFile);
+            Q_ASSERT(!testFile.isEmpty() && testFile.isLocalFile());
+
+            mainWindow->loadTest(testFile);
+        }
     }
 
     mainWindow->show();
-    QObject::connect(mainWindow->windowHandle(), &QWindow::visibleChanged, [](bool b){ if(!b) QCoreApplication::instance()->quit(); });
+    QObject::connect(mainWindow, &QWindow::visibleChanged, [](bool b){ if(!b) QCoreApplication::instance()->quit(); });
 
     return app.exec();
 }
