@@ -23,22 +23,21 @@
 #include <QDebug>
 #include <knewstuff_version.h>
 
-KNSResource::KNSResource(const Attica::Content& c, QString  category, QString  icon, KNSBackend* parent)
+KNSResource::KNSResource(const Attica::Content& c, QString  category, KNSBackend* parent)
     : AbstractResource(parent)
-    , m_status(KNS3::Entry::Downloadable)
     , m_content(c)
     , m_category(std::move(category))
-    , m_icon(std::move(icon))
     , m_entry(nullptr)
-{}
-
-KNSResource::~KNSResource()
 {
 }
 
+KNSResource::~KNSResource() = default;
+
 AbstractResource::State KNSResource::state()
 {
-    switch(m_status) {
+    if (!m_entry)
+        return None;
+    switch(m_entry->status()) {
         case KNS3::Entry::Invalid:
             return Broken;
         case KNS3::Entry::Downloadable:
@@ -55,17 +54,9 @@ AbstractResource::State KNSResource::state()
     return None;
 }
 
-void KNSResource::setStatus(KNS3::Entry::Status status)
-{
-    if(status!=m_status) {
-        m_status = status;
-        emit stateChanged();
-    }
-}
-
 QString KNSResource::icon() const
 {
-    return m_icon;
+    return qobject_cast<KNSBackend*>(parent())->iconName();
 }
 
 QString KNSResource::comment()
@@ -124,8 +115,8 @@ QString KNSResource::longDescription()
 
 void KNSResource::setEntry(const KNS3::Entry& entry)
 {
-    setStatus(entry.status());
     m_entry.reset(new KNS3::Entry(entry));
+    Q_EMIT stateChanged();
 }
 
 KNS3::Entry* KNSResource::entry() const
@@ -140,10 +131,7 @@ QString KNSResource::license()
 
 int KNSResource::size()
 {
-#if KNEWSTUFF_VERSION_MINOR > 3 and KNEWSTUFF_VERSION_MAJOR == 5
-    const
-#endif
-    Attica::DownloadDescription desc = m_content.downloadUrlDescription(0);
+    const Attica::DownloadDescription desc = m_content.downloadUrlDescription(0);
     return desc.size();
 }
 
@@ -164,10 +152,7 @@ QString KNSResource::origin() const
 
 QString KNSResource::section()
 {
-#if KNEWSTUFF_VERSION_MINOR > 3 and KNEWSTUFF_VERSION_MAJOR == 5
-    const
-#endif
-    Attica::DownloadDescription desc = m_content.downloadUrlDescription(0);
+    const Attica::DownloadDescription desc = m_content.downloadUrlDescription(0);
     return desc.category();
 }
 
