@@ -23,12 +23,13 @@
 
 #include <Transaction/Transaction.h>
 #include <PackageKit/Transaction>
+#include <QPointer>
 
 class PKTransaction : public Transaction
 {
     Q_OBJECT
     public:
-        explicit PKTransaction(AbstractResource* app, Transaction::Role role);
+        explicit PKTransaction(const QVector<AbstractResource*>& app, Transaction::Role role);
         PackageKit::Transaction* transaction();
 
         void cancel();
@@ -44,9 +45,14 @@ class PKTransaction : public Transaction
         void progressChanged(const QString&, PackageKit::Transaction::Status, uint);
         void eulaRequired(const QString &eulaID, const QString &packageID, const QString &vendor, const QString &licenseAgreement);
         void cancellableChanged();
+        void packageResolved(PackageKit::Transaction::Info info, const QString& packageId);
+        void submitResolve();
 
     private:
-        PackageKit::Transaction* m_trans;
+        QPointer<PackageKit::Transaction> m_trans;
+        const QVector<AbstractResource*> m_apps;
+
+        QMap<PackageKit::Transaction::Info, QStringList> m_newPackageStates;
 };
 
 #endif // PKTRANSACTION_H
