@@ -31,6 +31,7 @@
 #include <AppstreamQt/database.h>
 #include <functional>
 
+class AppstreamReviews;
 class AppPackageKitResource;
 class PackageKitUpdater;
 class PKTransaction;
@@ -63,6 +64,7 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         QString upgradeablePackageId(const PackageKitResource* res) const;
         QVector<AbstractResource*> resourcesByPackageName(const QString& name, bool updating) const;
         QVector<AppPackageKitResource*> extendedBy(const QString& id) const;
+        void fetchUpdates();
 
     public Q_SLOTS:
         void transactionCanceled(Transaction* t);
@@ -82,7 +84,6 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
     private:
         void addTransaction(PKTransaction* trans);
         void checkDaemonRunning();
-        void fetchUpdates();
         void acquireFetching(bool f);
 
         Appstream::Database m_appdata;
@@ -97,10 +98,12 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
             QHash<QString, AbstractResource*> packages;
             QHash<QString, QStringList> packageToApp;
             QHash<QString, QVector<AppPackageKitResource*>> extendedBy;
+            void clear() { *this = {}; }
         };
 
         Packages m_packages;
         Packages m_updatingPackages;
+        AppstreamReviews* const m_reviews;
 };
 
 #endif // PACKAGEKITBACKEND_H
