@@ -44,9 +44,7 @@ DiscoverNotifier::DiscoverNotifier(QObject * parent)
     updateStatusNotifier();
 }
 
-DiscoverNotifier::~DiscoverNotifier()
-{
-}
+DiscoverNotifier::~DiscoverNotifier() = default;
 
 void DiscoverNotifier::configurationChanged()
 {
@@ -141,7 +139,7 @@ QString DiscoverNotifier::message() const
 QString DiscoverNotifier::extendedMessage() const
 {
     uint securityCount = securityUpdatesCount();
-    uint count = updatesCount() + securityCount;
+    uint count = updatesCount();
     if (count > 0 && securityCount > 0) {
         QString allUpdates = i18ncp("First part of '%1, %2'",
                                     "1 package to update", "%1 packages to update", count);
